package com.diagbot.facade;

import com.diagbot.entity.BaseNodeInfo;
import com.diagbot.entity.node.Dept;
import com.diagbot.entity.node.LisName;
import com.diagbot.entity.node.LisSet;
import com.diagbot.entity.node.Medicine;
import com.diagbot.entity.node.PacsSubName;
import com.diagbot.entity.node.YiBaoDiseaseName;
import com.diagbot.entity.node.YiBaoOperationName;
import com.diagbot.entity.relationship.LisNameLisSet;
import com.diagbot.entity.relationship.PacsNamePacsSubName;
import com.diagbot.repository.DeptRepository;
import com.diagbot.repository.LisNameRepository;
import com.diagbot.repository.LisSetRepository;
import com.diagbot.repository.MedicineRepository;
import com.diagbot.repository.PacsNameRepository;
import com.diagbot.repository.PacsSubNameRepository;
import com.diagbot.repository.TransfusionRemindRepository;
import com.diagbot.repository.YiBaoDiseaseNameRepository;
import com.diagbot.repository.YiBaoOperationNameRepository;
import com.diagbot.util.BeanUtil;
import com.diagbot.util.ListUtil;
import com.diagbot.vo.ConceptVO;
import com.diagbot.vo.StaticKnowledgeNameVO;
import com.google.common.collect.Lists;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import java.util.TreeSet;
import java.util.stream.Collectors;

/**
 * @Description:
 * @Author:zhaops
 * @time: 2020/9/10 14:51
 */
@Component
public class ConceptFacade {
    @Autowired
    LisSetRepository lisSetRepository;

    @Autowired
    LisNameRepository lisNameRepository;

    @Autowired
    YiBaoDiseaseNameRepository yiBaoDiseaseRepository;

    @Autowired
    PacsNameRepository pacsNameRepository;

    @Autowired
    PacsSubNameRepository pacsSubNameRepository;

    @Autowired
    MedicineRepository medicineRepository;

    @Autowired
    YiBaoOperationNameRepository yiBaoOperationNameRepository;

    @Autowired
    DeptRepository deptRepository;

    @Autowired
    TransfusionRemindRepository transfusionRemindRepository;

    public List<String> getConceptNames(ConceptVO conceptVO) {
        if (ListUtil.isEmpty(conceptVO.getNames())) {
            return new ArrayList<>();
        }
        List<String> retList = Lists.newLinkedList();
        //type： 类型：1-化验大项、2-化验小项、3-辅检、4-诊断、5-药品、6-手术和操作、7-科室、8-输血
        switch (conceptVO.getType()) {
            case 1:
                List<LisSet> lisSetList = lisSetRepository.findByNameIn(conceptVO.getNames());
                if (ListUtil.isNotEmpty(lisSetList)) {
                    retList = lisSetList.stream()
                            .map(i -> i.getName())
                            .distinct()
                            .collect(Collectors.toList());
                }
                break;
            case 2:
                List<LisName> lisNameList = lisNameRepository.findByNameIn(conceptVO.getNames());
                if (ListUtil.isNotEmpty(lisNameList)) {
                    retList = lisNameList.stream()
                            .map(i -> i.getName())
                            .distinct()
                            .collect(Collectors.toList());
                }
                break;
            case 3:
                List<BaseNodeInfo> pacsNameList = pacsNameRepository.findByNameInMultipleLabel(conceptVO.getNames());
                if (ListUtil.isNotEmpty(pacsNameList)) {
                    retList = pacsNameList.stream()
                            .map(i -> i.getName())
                            .distinct()
                            .collect(Collectors.toList());
                }
                break;
            case 4:
                List<YiBaoDiseaseName> yiBaoDiseaseNameList = yiBaoDiseaseRepository.findByNameIn(conceptVO.getNames());
                if (ListUtil.isNotEmpty(yiBaoDiseaseNameList)) {
                    retList = yiBaoDiseaseNameList.stream()
                            .map(i -> i.getName())
                            .distinct()
                            .collect(Collectors.toList());
                }
                break;
            case 5:
                List<Medicine> medicineList = medicineRepository.findByNameIn(conceptVO.getNames());
                if (ListUtil.isNotEmpty(medicineList)) {
                    retList = medicineList.stream()
                            .map(i -> i.getName())
                            .distinct()
                            .collect(Collectors.toList());
                }
                break;
            case 6:
                List<YiBaoOperationName> yiBaoOperationNameList = yiBaoOperationNameRepository.findByNameIn(conceptVO.getNames());
                if (ListUtil.isNotEmpty(yiBaoOperationNameList)) {
                    retList = yiBaoOperationNameList.stream()
                            .map(i -> i.getName())
                            .distinct()
                            .collect(Collectors.toList());
                }
                break;
            case 7:
                List<Dept> deptList = deptRepository.findByNameIn(conceptVO.getNames());
                if (ListUtil.isNotEmpty(deptList)) {
                    retList = deptList.stream()
                            .map(i -> i.getName())
                            .distinct()
                            .collect(Collectors.toList());
                }
                break;
            case 8:
                List<String> transfusionNames = transfusionRemindRepository.findTransfusionByTypeIn(conceptVO.getNames());
                if (ListUtil.isNotEmpty(transfusionNames)) {
                    retList = transfusionNames;
                }
                break;
        }
        return retList;
    }

    /**
     * 取上级静态知识
     *
     * @param staticKnowledgeNameVO
     * @return
     */
    public StaticKnowledgeNameVO getSuperName(StaticKnowledgeNameVO staticKnowledgeNameVO) {
        //类型：1-诊断、2-药品、3-检验套餐、4-检验细项、5-检查、6-检查子项、7-手术和操作
        StaticKnowledgeNameVO retName = new StaticKnowledgeNameVO();
        BeanUtil.copyProperties(staticKnowledgeNameVO, retName);
        switch (staticKnowledgeNameVO.getType()) {
            case 4:
                List<LisName> lisNameList = lisNameRepository.findByNameIs(staticKnowledgeNameVO.getName());
                if (ListUtil.isNotEmpty(lisNameList)) {
                    LisName lisName = lisNameList.get(0);
                    Set<LisNameLisSet> lisNameLisSetSet = lisName.getLisNamelissets();
                    if (lisNameLisSetSet != null && lisNameLisSetSet.size() > 0) {
                        //升序排序
                        Set<LisNameLisSet> sortLisNameLisSetSet
                                = new TreeSet<LisNameLisSet>((o1, o2) -> o1.getLisSet().getName().compareTo(o2.getLisSet().getName()));
                        sortLisNameLisSetSet.addAll(lisNameLisSetSet);
                        for (LisNameLisSet lisNameLisSet : sortLisNameLisSetSet) {
                            if (lisNameLisSet.getLisSet().getIs_kl().equals(1)) {
                                retName.setName(lisNameLisSet.getLisSet().getName());
                                retName.setType(3);
                                break;
                            }
                        }
                    }
                }
                break;
            case 6:
                List<PacsSubName> pacsSubNameList = pacsSubNameRepository.findByNameIs(staticKnowledgeNameVO.getName());
                if (ListUtil.isNotEmpty(pacsSubNameList)) {
                    PacsSubName pacsSubName = pacsSubNameList.get(0);
                    Set<PacsNamePacsSubName> pacsNamePacsSubNameSet = pacsSubName.getPacsNamePacsSubNames();
                    if (pacsNamePacsSubNameSet != null && pacsNamePacsSubNameSet.size() > 0) {
                        //升序排序
                        Set<PacsNamePacsSubName> sortPacsNamePacsSubNameSet
                                = new TreeSet<PacsNamePacsSubName>((o1, o2) -> o1.getPacsName().getName().compareTo(o2.getPacsName().getName()));
                        sortPacsNamePacsSubNameSet.addAll(pacsNamePacsSubNameSet);
                        for (PacsNamePacsSubName pacsNamePacsSubName : sortPacsNamePacsSubNameSet) {
                            if (pacsNamePacsSubName.getPacsName().getIs_kl().equals(1)) {
                                retName.setName(pacsNamePacsSubName.getPacsName().getName());
                                retName.setType(5);
                            }
                        }
                    }
                }
                break;
            default:
                break;
        }
        return retName;
    }

    /**
     * 取上级静态知识（批量）
     *
     * @param nameList
     * @return
     */
    public List<StaticKnowledgeNameVO> getSuperNameBatch(List<StaticKnowledgeNameVO> nameList) {
        List<StaticKnowledgeNameVO> retList = Lists.newLinkedList();
        if (ListUtil.isNotEmpty(nameList)) {
            nameList.forEach(item -> {
                retList.add(getSuperName(item));
            });
        }
        return retList;
    }
}