package com.diagbot.web;

import com.diagbot.dto.RespDTO;
import com.diagbot.facade.ConceptFacade;
import com.diagbot.facade.StaticKnowledgeFacade;
import com.diagbot.vo.HasStaticKnowledgeVO;
import com.diagbot.vo.StaticKnowledgeNameVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.List;

/**
 * @Description:
 * @Author:zhaops
 * @time: 2020/8/25 14:16
 */
@RestController
@RequestMapping("/staticKnowledge")
@Api(value = "静态信息相关API", tags = { "静态信息相关API" })
@SuppressWarnings("unchecked")
public class StaticKnowledgeController {

    @Autowired
    private StaticKnowledgeFacade staticKnowledgeFacade;
    @Autowired
    private ConceptFacade conceptFacade;


    @ApiOperation(value = "更新是否有静态信息状态[zhaops]",
            notes = "type： 术语类型<br>" +
                    "name： 标准术语名称<br>" +
                    "hasInfo：是否有静态知识：0-无，1-有<br>")
    @PostMapping("/updateHasInfoStatus")
    public RespDTO<Boolean> updateHasInfoStatus(@Valid @RequestBody HasStaticKnowledgeVO hasStaticKnowledgeVO) {
        Boolean data = staticKnowledgeFacade.updateHasInfoStatus(hasStaticKnowledgeVO);
        return RespDTO.onSuc(data);
    }

    @ApiOperation(value = "取上级静态知识[zhaops]",
            notes = "type： 术语类型<br>" +
                    "name： 标准术语名称<br>")
    @PostMapping("/getSuperName")
    public RespDTO<StaticKnowledgeNameVO> getSuperName(@Valid @RequestBody StaticKnowledgeNameVO staticKnowledgeNameVO) {
        StaticKnowledgeNameVO data = conceptFacade.getSuperName(staticKnowledgeNameVO);
        return RespDTO.onSuc(data);
    }

    @ApiOperation(value = "取上级静态知识（批量）[zhaops]",
            notes = "type： 术语类型<br>" +
                    "name： 标准术语名称<br>")
    @PostMapping("/getSuperNameBatch")
    public RespDTO<List<StaticKnowledgeNameVO>> getSuperNameBatch(@Valid @RequestBody List<StaticKnowledgeNameVO> staticKnowledgeNameVO) {
        List<StaticKnowledgeNameVO> data = conceptFacade.getSuperNameBatch(staticKnowledgeNameVO);
        return RespDTO.onSuc(data);
    }

    @ApiOperation(value = "批量更新静态信息状态[kwz]")
    @PostMapping("/BatchUpdateHasInfoStatus")
    public RespDTO<Boolean> BatchUpdateHasInfoStatus() {
        Boolean data = staticKnowledgeFacade.batchUpdateHasInfoStatus();
        return RespDTO.onSuc(data);
    }
}
